@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef WEBENGINEEXPORTHTMLPAGEJOB_H
-#define WEBENGINEEXPORTHTMLPAGEJOB_H
+#pragma once
 
-#include <QObject>
 #include "webengineviewer_export.h"
+#include <QObject>
 class QWebEngineView;
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 /**
  * @brief The WebEngineExportHtmlPageJob class
  * @author Laurent Montel <montel@kde.org>
@@ -20,7 +20,7 @@ class WEBENGINEVIEWER_EXPORT WebEngineExportHtmlPageJob : public QObject
     Q_OBJECT
 public:
     explicit WebEngineExportHtmlPageJob(QObject *parent = nullptr);
-    ~WebEngineExportHtmlPageJob();
+    ~WebEngineExportHtmlPageJob() override;
 
     void start();
 
@@ -31,12 +31,8 @@ Q_SIGNALS:
     void failed();
     void success(const QString &filename);
 
-private Q_SLOTS:
-    void slotSaveHtmlToPage(const QString &text);
-
 private:
+    WEBENGINEVIEWER_NO_EXPORT void slotSaveHtmlToPage(const QString &text);
     QWebEngineView *mEngineView = nullptr;
 };
 }
-
-#endif // WEBENGINEEXPORTHTMLPAGEJOB_H
