@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -30,10 +30,9 @@ Q_SIGNALS:
     void finished(const WebEngineViewer::WebHitTestResult &result);
 
 private Q_SLOTS:
-    void handleHitTest(const QVariant &result);
+    WEBENGINEVIEWER_NO_EXPORT void handleHitTest(const QVariant &result);
 
 private:
     std::unique_ptr<WebHitTestPrivate> const d;
 };
 }
-
